@@ -1,4 +1,4 @@
-GOOF----LE-4-2.0      ] 4       h      ] g  guile	 	g  define-module*	 	 	g  web	g  client	 		g  filenameS	
+GOOF----LE-4-2.0      ] 4  h      ] g  guile	 	g  define-module*	 	 	g  web	g  client	 		g  filenameS	
 f  web/client.scm	g  importsS	g  rnrs	
 g  bytevectors	
  	 	g  ice-9	g  binary-ports	 	 	g  iconv	 	 	g  rdelim	 	 	g  request	 	 	g  response	 	 	 g  uri	!  	"! 	#g  http	$# 	%$ 	&g  srfi	'g  srfi-1	(&' 	)( 	*g  srfi-9	+&* 	,+ 	-g  gnu	.&*- 	/. 	0"%),/ 	1g  exportsS	2g  current-http-proxy	3g  open-socket-for-uri	4g  http-get	5g  	http-get*	6g  	http-head	7g  	http-post	8g  http-put	9g  http-delete	:g  
@@ -8,26 +8,25 @@ http_proxy	Cf   	Dg  string?	Eg  string->uri	Fg  error	Gf  Invalid URI
 ensure-uri	Lg  throw-bad-struct	M+L 	N+L 	Og  uri-port	Pg  delete-duplicates	Qg  getaddrinfo	Rg  uri-host	Sg  number->string	Tg  symbol->string	Ug  
 uri-scheme	Vg  AI_NUMERICSERV	Wg  
 addrinfo:addr	Xg  %default-port-encoding	Yg  socket	Zg  addrinfo:fam	[g  SOCK_STREAM	\g  
-IPPROTO_IP	]g  catch	^g  system-error	_g  connect	`g  setvbuf	ag  _IOFBF	bg  
-setsockopt	cg  
-SOL_SOCKET	dg  	SO_RCVBUF	eg  set-http-proxy-port?!	fg  close	gg  throw	hg  	<request>	ih 	jh 	kg  
-assoc-set!	lg  	copy-tree	mg  %%<request>-set-fields	ng  extend-request	og  request-content-type	pg  
-text/plain	qp 	rg  assq-ref	sg  charset	tg  sanitize-request	ug  content-type	vg  append	wv 	xv 	yf  utf-8	zg  string->bytevector	{g  
-procedure?	|g  call-with-encoded-output-string	}g  bytevector?	~g  request-content-length	g  bytevector-length f  bad content-length g  content-length f  unexpected body type f  content-length, but no body g  assq g  transfer-encoding g  request-headers f  *transfer-encoding not allowed with no body g  vu8
+IPPROTO_IP	]g  catch	^g  system-error	_g  connect	`g  setvbuf	ag  _IOFBF	bg  set-http-proxy-port?!	cg  close	dg  throw	eg  	<request>	fe 	ge 	hg  
+assoc-set!	ig  	copy-tree	jg  %%<request>-set-fields	kg  extend-request	lg  request-content-type	mg  
+text/plain	nm 	og  assq-ref	pg  charset	qg  sanitize-request	rg  content-type	sg  append	ts 	us 	vf  utf-8	wg  string->bytevector	xg  
+procedure?	yg  call-with-encoded-output-string	zg  bytevector?	{g  request-content-length	|g  bytevector-length	}f  bad content-length	~g  content-length	f  unexpected body type f  content-length, but no body g  assq g  transfer-encoding g  request-headers f  *transfer-encoding not allowed with no body g  vu8
 	  j    g  response-content-length g  response-content-type g  text-content-type? g  bytevector->string f  
 iso-8859-1 g  decode-response-body g  bodyS  g  portS 	 g  methodS 	 g  versionS 	 g  keep-alive?S 	 g  headersS 	 g  decode-body?S 	 g  
 streaming?S 	 g  requestS 		  	 g  GET  g  
 build-request g  
-connection f  g  
+connection c  g  
 write-request g  write-request-body g  force-output g  request-port g  
 read-response g  request-method g  HEAD g  
 close-port g  response-body-port g  decode?S g  read-response-body 	 	 g  
 extra-headersS 	   g  issue-deprecation-warning f  HThe #:extra-headers argument to http-get has been renamed to #:headers.  f  Please update your code.   f  "`http-get*' has been deprecated.   f  BInstead, use `http-get' with the #:streaming? #t keyword argument. g  make-syntax-transformer     g  define-http-verb g  macro g  $sc-dispatch     g  any   g  
-syntax-object g  define* g  top   g  ribcage g  dummy g  	http-verb g  method g  doc   g  m-VDeDDqp7iv@Xr5T1dGJ7Dj-5361     f  l-VDeDDqp7iv@Xr5T1dGJ7Dj-5366 f  l-VDeDDqp7iv@Xr5T1dGJ7Dj-5367 f  l-VDeDDqp7iv@Xr5T1dGJ7Dj-5368 f  l-VDeDDqp7iv@Xr5T1dGJ7Dj-5369       g  x     f  l-VDeDDqp7iv@Xr5T1dGJ7Dj-5363       g  hygiene        g  keyS   g  body       g  port   3      g  version   g  quote          g  keep-alive?     g  headers       g  decode-body?    g  
-streaming?   	 	 
+syntax-object g  define* g  top   g  ribcage g  dummy g  	http-verb g  method g  doc   g  m-3b9wII1MSyAPqfhFqDbSZZ-5768     f  l-3b9wII1MSyAPqfhFqDbSZZ-5773 f  l-3b9wII1MSyAPqfhFqDbSZZ-5774 f  l-3b9wII1MSyAPqfhFqDbSZZ-5775 f  l-3b9wII1MSyAPqfhFqDbSZZ-5776       g  x     f  l-3b9wII1MSyAPqfhFqDbSZZ-5770       g  hygiene        g  keyS   g  body       g  port   3      g  version   g  quote          g  keep-alive?     g  headers       g  decode-body?      g  
+streaming?    	    	 
    
-    
- g  syntax-violation  f  -source expression failed to match any pattern			 g  POSTg  PUTg  DELETEg  TRACEg  OPTIONSC 5 ho  -  ]4	
+ 	
+
+ g  syntax-violation  f  -source expression failed to match any pattern			 g  POSTg  PUTg  DELETEg  TRACEg  OPTIONSC 5     hho  -  ]4	
 01<5 4? >  "  G   4@i4AiB5  C$  "    52RDEFGJ      h@      ]4 5$   6"   6 $   &   C""             g  
 uri-or-string
 		:  g  filenamef  web/client.scm
@@ -37,20 +36,18 @@ uri-or-string
 ensure-uri CKR2KJNOPQRSTUVW   h   |   ]4 545C      t       g  ai1
 		 g  ai2		  g  filenamef  web/client.scm
 	P			Q		
-	Q	%		Q		 			   CXYZ[\]^_W`abcde 	hh      ] 4L4L5>  "  G  4L>  "  G  4L0 >  "  G  M $  4L>  "  G  "   LC       g  filenamef  web/client.scm
+	Q	%		Q		 			   CXYZ[\]^_W`ab       hP   q   ] 4L4L5>  "  G  4L>  "  G  M $  4L>  "  G  "   LC i       g  filenamef  web/client.scm
 	Y			Z	
 		Z			Z	
 		]	
-	0	_	
-	;	_	-	@	_	
-	N	a	
-	O	a	 		h
-   Cfg       h0      -  1  3 4L>  "  G  L (   @LL 6 ~       g  args
+	5	_	
+	6	_	 		O
+   Ccd       h0      -  1  3 4L>  "  G  L (   @LL 6 ~       g  args
 			/  g  filenamef  web/client.scm
-	c		
-	e	
-		f		"	f	
-	(	g		-	h		/	h	 			/
+	a		
+	c	
+		d		"	d	
+	(	e		-	f		/	f	 			/
 
 
    C 
@@ -69,13 +66,13 @@ uri-or-string
 http-proxy	  g  uri		  g  	addresses		  g  port		B  g  loop	    g  filenamef  web/client.scm
 	C
 		E			F			F		%	F		*	H		B	H		E	I		H	J		M	J		k	K		w	L	 	|	L	0 	L	  	M	 	J	 	I	 	S	 	   g  nameg  open-socket-for-urig  
-documentationf  9Return an open input/output port for a connection to URI. C3RjklNmn  hh     - 1 3  &  3 
+documentationf  9Return an open input/output port for a connection to URI. C3RghiNjk  hh     - 1 3  &  3 
   	44 	55 	 	 "  	4 5(  C@              g  r
 			a g  k			a g  v				a g  
 additional				a g  r		N	a  g  filenamef  web/client.scm
-	j
-		k		"	l		%	l	"	,	l	-	.	l	"	4	l		9	k		N	k		V	n		a	p	 			a	
-	  g  nameg  extend-request CnRDoqrstnuxyz{|}~FjN      h    ]$ 45$  T4 545$   "  4 4	
+	h
+		i		"	j		%	j	"	,	j	-	.	j	"	4	j		9	i		N	i		V	l		a	n	 			a	
+	  g  nameg  extend-request CkRDlnopqkruvwxyz{|F}~gN      h    ]$ 45$  T4 545$   "  4 4	
  554$  "  
 5645$  T4 545$   "  4 4	
  554
@@ -83,7 +80,7 @@ additional				a g  r		N	a  g  filenamef  web/client.scm
 5645$  K4 545$  $   "  45"  4 5D64 5$  "
 $  "  4>  "  G  "  <4 &  	 	"  	4 55$  4>  "  G  "    D   }      g  request
 	 g  body	 g  type			g g  declared-charset		(	g g  type		{  g  declared-charset	   g  rlen	  g  blen	  g  length	)  	g  filenamef  web/client.scm
-	s
+	q
 	 			 		 		 		 	/	 		 		 		$ 	'	& 	2	( 		( 		2 		9 		? 	#	@ 		H 	)	I 		P 		Q 		[ 		c 	)	e 		g 		h 		r 		s 		y 	(	{ 		{ 		~ 	  	'  	2  	  	  	  	  	#  	  	)  	  	  	  	  	)  	  	  		  	  	  	  	  	  	  	  	  	  	 	 	- 	 	  	" 	# 	) 	1 	4 	9 	
 > 	B 	G 	T 	X 	[ 	)u 	y 	
 z 	~ 	 	 	 	 T		  g  nameg  sanitize-requestg  
@@ -104,14 +101,14 @@ documentation k 0"   S   a   n   i   t   i   z   e   "       t   h   e       g 
    p   a   r   t   i   c   u   l   a   r       t   i   m   e   .   
    
    N   o   t   e       t   h   a   t       w   e       r   e   l   y       o   n       t   h   e       r   e   q   u   e   s   t       i   t   s   e   l   f       a   l   r   e   a   d   y       h   a   v   i   n   g       b   e   e   n       v   a   l   i   d   a   t   e   d   ,   
-   a   s       i   s       t   h   e       c   a   s   e       b   y       d   e   f   a   u   l   t       w   i   t   h       a       r   e   q   u   e   s   t       r   e   t   u   r   n   e   d       b   y       `   b   u   i   l   d   -   r   e   q   u   e   s   t   '   .    CtR}rsF 
+   a   s       i   s       t   h   e       c   a   s   e       b   y       d   e   f   a   u   l   t       w   i   t   h       a       r   e   q   u   e   s   t       r   e   t   u   r   n   e   d       b   y       `   b   u   i   l   d   -   r   e   q   u   e   s   t   '   .    CqRz|opF} 
    h     ]"$  45$  {4 545"  D4 5$  245$  #45$  "  	6CC$  $  "
 6"
 6C             g  response
 	  g  body	  g  rlen		!  g  blen		!  g  t		0	m g  t		R	e  g  filenamef  web/client.scm
  
 	 			 		 		 		 		! 		* 		0 		9 		> 	#	@ 		D 	
-	I 	,	N 	6	P 	A	R 	,	R 	(	b 	,	g 		m 		x 		| 	  	  	  	  	 	 	  g  nameg  decode-response-body CR3KtjN   h    - /   
+	I 	,	N 	6	P 	A	R 	,	R 	(	b 	,	g 		m 		x 		| 	  	  	  	  	 	 	  g  nameg  decode-response-body CR3KqgN   h    - /   
 0  
  3 #  #  	4 5#  #  #  #  #  #  	#  -44 5	$  "  
 5		4	>  G 
@@ -146,7 +143,7 @@ streaming?S	g  requestS		 
 extra-headers		  g  headers		  g  decode-body?		  g  
 streaming?		   	g  filenamef  web/client.scm
  
-	# 		3 		S 	/	Z 	A	t		u		y		{	 	 	 	 
+	# 		3 		S 	/	Z 	A	t		u		y		{	 	 	 	 
 	 
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  
 extra-headersS	g  headersS	g  decode-body?S	g  
@@ -181,23 +178,22 @@ documentation   k C   o   n   n   e   c   t       t   o       t   h   e       s
 6             g  uri
 	  g  body	  g  port		  g  version		  g  keep-alive?		  g  
 extra-headers		  g  headers		  g  decode-body?		   g  filenamef  web/client.scm
-#
-	#%		3&		S(	0	Z(	B	f+		j,		l-		q+	 .	 	 
+!
+	##		3$		S&	0	Z&	B	f)		j*		l+		q)	 ,	 	 
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  
 extra-headersS	g  headersS	g  decode-body?S	   g  nameg  	http-get*g  
-documentationf  2Deprecated in favor of (http-get #:streaming? #t). C5R4	
- 	 h(   i   ] C     a       g  dummy
-		# g  	http-verb		# g  method			# g  doc			#  		#	   C      h(      ]	4 5$  @ 6             g  x
+documentationf  2Deprecated in favor of (http-get #:streaming? #t). C5R4 	 h(   i   ] C     a       g  dummy
+		# g  	http-verb		# g  method			# g  doc			#  		#	   C      h(      ]	4 5$  @ 6             g  x
 		" g  tmp		"  g  filenamef  web/client.scm
-2
+0
  		"  g  
-macro-typeg  syntax-rulesg  patternsg  	http-verbg  methodg  doc   C5R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	
+macro-typeg  syntax-rulesg  patternsg  	http-verbg  methodg  doc   C5R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6       g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-B
-	eC		B
+@
+	eA		@
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  	http-headg  
@@ -210,13 +206,13 @@ documentation k @F   e   t   c   h       m   e   s   s   a   g   e       h   e 
    
    R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d          #   f      .           R   e   s   p   o   n   s   e   s       t   o       H   E   A   D   
    r   e   q   u   e   s   t   s       d   o       n   o   t       h   a   v   e       a       b   o   d   y   .           T   h   e       s   e   c   o   n   d       v   a   l   u   e       i   s       o   n   l   y       r   e   t   u   r   n   e   d       s   o       t   h   a   t   
-   o   t   h   e   r       p   r   o   c   e   d   u   r   e   s       c   a   n       t   r   e   a   t       a   l   l       o   f       t   h   e       h   t   t   p   -   f   o   o       v   e   r   b   s       i   d   e   n   t   i   c   a   l   l   y   .    C6R3        h   i  - /   0   3 #  #  	4 5#  #  #  #  #   	
+   o   t   h   e   r       p   r   o   c   e   d   u   r   e   s       c   a   n       t   r   e   a   t       a   l   l       o   f       t   h   e       h   t   t   p   -   f   o   o       v   e   r   b   s       i   d   e   n   t   i   c   a   l   l   y   .    C6R3        h   i  - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6 a      g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-O
-	eP		O
+M
+	eN		M
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  	http-postg  
@@ -226,13 +222,13 @@ documentation k P   o   s   t       d   a   t   a       t   o       t   h   e  
    m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
    a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
    
-   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C7R3    h   ]  - /   0   3 #  #  	4 5#  #  #  #  #   	
+   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C7R3    h   ]  - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6 U      g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-Y
-	eZ		Y
+W
+	eX		W
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  http-putg  
@@ -242,13 +238,13 @@ documentation  k P   u   t       d   a   t   a       a   t       t   h   e     
    m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
    a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
    
-   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C8R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	
+   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C8R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6 }      g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-c
-	ed		c
+a
+	eb		a
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  http-deleteg  
@@ -258,13 +254,13 @@ documentation   k D   e   l   e   t   e       d   a   t   a       a   t       t
    m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
    a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
    
-   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C9R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	
+   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C9R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6       g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-m
-	en		m
+k
+	el		k
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  
@@ -275,13 +271,13 @@ documentationk dS   e   n   d       a   n       H   T   T   P       "   T   R  
    m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
    a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
    
-   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C:R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	
+   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C:R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	
 
 6       g  uri
 		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
 streaming?			  g  filenamef  web/client.scm
-w
-	ex		w
+u
+	ev		u
  		
 g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
 streaming?S	   g  nameg  http-optionsg  
@@ -298,17 +294,17 @@ documentation  k  Q   u   e   r   y       c   h   a   r   a   c   t   e   r   i
 	-	9		2	9		8	9	'	:	9		:	9		@	:	,	A	:		E	:		Q	9		T	8
 n	=
 	C
-	V	j
-	s
- K 
+	&	h
+	q
+  
 % 
 = 
-@#
-LB
-S,O
-Z8Y
-apc
-h$m
-ow
- 	o
+@!
+K@
+RM
+ZW
+a@a
+gk
+odu
+ 	of
    C6 
\ No newline at end of file
